Templates — AstroCabTools 0.9.11 documentation

# Templates

## Overview

To test the functionalities of each tool, there are multiple templates avaliable to use them.

## Mrs_spec_chan templates

The templates for this tool can be downloaded from this first link.

## Mrs_det_plot templates

The templates for this tool can be downloaded from this second link.

## Fit_line templates

The templates for this tool can be downloaded from this third link.